//
// timezone-del-bogus-win-links.cpp
//
// Bill Seymour, 2024-03-03
//
// This is the program that deletes bogus "symlinks"
// in a Windows Zoneinfo directory.  Such files are created
// by unzipping zip archives made from some Linux box's
// /usr/share/zoneinfo.
//
// This is an optional preparation step for using Bill's timezone
// class (see https://www.cstdbill.com/civil-time/timezone.html).
//
// This file is in the public domain.
//

#include "timezone-win-links.hpp" // includes <string>

#include <iostream> // cerr
#include <cstddef>  // size_t
#include <cstdio>   // remove

namespace {

namespace tw = timezone_win;

bool do_remove(const std::string& input)
{
    //
    // First, find the link name in an input line of the form,
    //
    //   L real-name link-name
    //

    // The end of the first name:
    std::size_t this_beg = input.find_first_of(" \t", 3);

    // The beginning of the second name:
    this_beg = input.find_first_not_of(" \t", this_beg);
    if (this_beg == std::string::npos)
    {
        std::cerr << "Invalid input format \"" << input << "\"\n";
        return false;
    }

    // The end of the second name:
    std::size_t this_end = input.find_first_of(" \t", this_beg);
    if (this_end == std::string::npos)
    {
        this_end = input.size();
    }

    //
    // Make the full path.
    //
    std::string fn(tw::tzdir);
    fn.append(1, '\\');
    fn.append(input, this_beg, this_end - this_beg);
    tw::fix_sep(fn);

    //
    // Delete the file.
    //
    if (std::remove(fn.c_str()) != 0)
    {
        std::cerr << "Can't delete " << fn << '\n';
    }
    // but still report success so that we keep trying with other files.
    return true;
}

} // anonymous namespace

int main(int argc, char** argv)
{
    if (argc != 2)
    {
        std::cerr << "Usage:  timezone-del-bogus-win-links tz-root-directory\n";
        return EXIT_FAILURE;
    }
    tw::tzdir.assign(argv[1]);

    return tw::main_loop(do_remove);
}

// End of timezone-del-bogus-win-links
