//
// timezone-win-links.hpp
//
// Bill Seymour, 2024-03-03
//
// This is the header for the two programs that deal with symbolic links
// on a Windows file system.  The two programs are optional preparation steps
// for using Bill's timezone class with Zoneinfo's TZif files on Windows
// (see https://www.cstdbill.com/civil-time/timezone.html).
//
// This file is in the public domain.
//

#ifndef TIMEZONE_WIN_LINKS_HPP_INCLUDED
#define TIMEZONE_WIN_LINKS_HPP_INCLUDED

#include <string>

namespace timezone_win {

//
// The root directory for the Zoneinfo TZif files (set in main()):
//
extern std::string tzdir;

//
// Assure that we have CP/M directory separators:
//
inline void fix_sep(std::string& path)
{
    for (char& c : path)
    {
        if (c == '/')
        {
            c = '\\';
        }
    }
}

//
// Make one symlink, return whether successful:
//
bool make_symlink(const std::string& link_path, const std::string& target_path);

//
// Read [tzdir]\tzdata.zi, call action with each Link line,
// return EXIT_SUCCESS or EXIT_FAILURE:
//
typedef bool (*action)(const std::string&);
int main_loop(action);

} // namespace timezone_win

#endif // TIMEZONE_WIN_LINKS_HPP_INCLUDED
